@@ -4,10 +4,6 @@ pub mod link_rel;
 pub mod micropub;
 pub mod webmention;
 
-use shadow_rs::shadow;
-
-shadow!(build);
-
 #[cfg(test)]
 mod test;
 
@@ -42,7 +38,7 @@ pub trait IConfiguration {
     /// Define the base request.
     fn request(&self, reason: Option<String>) -> reqwest::Client {
         let agent = if IN_BUILT_APP_USER_AGENT == self.user_agent() {
-            IN_BUILT_APP_USER_AGENT.to_owned() + "/-git" + build::COMMIT_HASH
+            IN_BUILT_APP_USER_AGENT.to_owned()
         } else {
             format!("{} {}", self.user_agent(), IN_BUILT_APP_USER_AGENT)
         };
